pub struct ClearEntityChangesSet;Expand description
When entities are updated and changes from the current tick are cleared.
Systems that need to observe changes to entities (Such as the difference
between Position and OldPosition) should run before this set (and
probably after InitEntitiesSet).
This set lives in [PostUpdate].