pub struct InitEntitiesSet;Expand description
When new Minecraft entities are initialized and added to
EntityManager.
Systems that need Minecraft entities to be in a valid state should run after this set.
This set lives in [PostUpdate].