pub struct OldPosition(/* private fields */);Expand description
The value of Position from the end of the previous tick.
NOTE: You should not modify this component after the entity is spawned.
Implementations
Methods from Deref<Target = DVec3>
pub const ZERO: DVec3
pub const ONE: DVec3
pub const NEG_ONE: DVec3
pub const MIN: DVec3
pub const MAX: DVec3
pub const NAN: DVec3
pub const INFINITY: DVec3
pub const NEG_INFINITY: DVec3
pub const X: DVec3
pub const Y: DVec3
pub const Z: DVec3
pub const NEG_X: DVec3
pub const NEG_Y: DVec3
pub const NEG_Z: DVec3
pub const AXES: [DVec3; 3]
pub const USES_CORE_SIMD: bool = false
pub const USES_NEON: bool = false
pub const USES_SCALAR_MATH: bool = true
pub const USES_SSE2: bool = false
pub const USES_WASM_SIMD: bool = false
pub const USES_WASM32_SIMD: bool = false